@@ -30,10 +30,12 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <pwd.h>
+#include <libintl.h>
 
 #include <dbus/dbus.h>
 #include <libhal.h>
 
+#define _(str) gettext(str)
 
 #define SYSTEMDIR LOCALSTATEDIR "/lib/" PACKAGE 
 #define DIRHOME "/." PACKAGE "-mount"
@@ -60,18 +62,20 @@ static int halevt_mount_parse_file(const char *file)
   char *next;
   char *current;
   halevt_mount_udi *new_udi;
+  int line_nr = 0;
 
   if (fd == NULL)
   {
-    fprintf(stderr, "Error opening %s: %s", file, strerror(errno));
+    fprintf(stderr, _("Error opening %s: %s\n"), file, strerror(errno));
     return 0;
   }
   while ((fgets(line, 1023, fd)) != NULL)
   {
+     line_nr++;
      if ((new_udi = malloc(sizeof(halevt_mount_udi))) == NULL) { return 0; }
 
      if (strlen (line) < 1) { 
-        fprintf (stderr, "Empty line\n");
+        fprintf (stderr, _("Empty line\n"));
         continue ;
      }
      if (line[strlen (line) - 1] == '\n') { line[strlen (line) - 1] = '\0';}
@@ -119,19 +123,19 @@ static int halevt_mount_parse_file(const char *file)
      }
      if (strlen (new_udi->udi) == 0) 
      { 
-        fprintf(stderr, "Empty udi\n");
+        fprintf(stderr, _("Empty udi: line %d\n"), line_nr);
         continue; 
      }
      
      if ((new_udi->device != NULL) && strlen (new_udi->device) == 0) 
      { 
-        fprintf(stderr, "Empty device\n");
+        fprintf(stderr, _("Empty device: line %d\n"), line_nr);
         new_udi->device = NULL;
      }
 
      if ((new_udi->mountpoint != NULL) && strlen (new_udi->mountpoint) == 0) 
      { 
-        fprintf(stderr, "Empty mountpoint\n");
+        fprintf(stderr, _("Empty mountpoint: line %d\n"), line_nr);
         new_udi->mountpoint = NULL;
      }
      new_udi->next = udi_device_mountpoint_root;
@@ -147,7 +151,7 @@ void halevt_mount_check_dbus_error(DBusError *error)
 {
   if (dbus_error_is_set(error))
   {
-    fprintf (stderr, "DBus Error %s: %s\n", error->name, error->message);
+    fprintf (stderr, _("DBus Error %s: %s\n"), error->name, error->message);
     dbus_error_free(error);
   }
 }
@@ -180,7 +184,7 @@ int halevt_mount_check_udi(halevt_mount_udi *checked_udi, LibHalContext *hal_ctx
   if (! libhal_device_property_exists (hal_ctx, checked_udi->udi, "block.is_volume", &dbus_error))
   {
     if (warn)
-      fprintf (stderr, "udi %s don't seem to be a volume\n", checked_udi->udi);
+      fprintf (stderr, _("udi %s don't seem to be a volume\n"), checked_udi->udi);
     halevt_mount_check_dbus_error (&dbus_error);
     return 0;
   }
@@ -190,7 +194,7 @@ int halevt_mount_check_udi(halevt_mount_udi *checked_udi, LibHalContext *hal_ctx
   if (! libhal_device_get_property_bool (hal_ctx, checked_udi->udi, "block.is_volume", &dbus_error))
   {
     if (warn)
-      fprintf (stderr, "udi %s isn't a volume\n", checked_udi->udi);
+      fprintf (stderr, _("udi %s isn't a volume\n"), checked_udi->udi);
     halevt_mount_check_dbus_error (&dbus_error);
     return 0;
   }
@@ -201,7 +205,7 @@ int halevt_mount_check_udi(halevt_mount_udi *checked_udi, LibHalContext *hal_ctx
   if (! libhal_device_property_exists (hal_ctx, checked_udi->udi, "block.device", &dbus_error))
   {
     if (warn)
-      fprintf (stderr, "udi %s don't seem to be a block device\n", checked_udi->udi);
+      fprintf (stderr, _("udi %s don't seem to be a block device\n"), checked_udi->udi);
     halevt_mount_check_dbus_error (&dbus_error);
     return 0;
   }
@@ -211,20 +215,20 @@ int halevt_mount_check_udi(halevt_mount_udi *checked_udi, LibHalContext *hal_ctx
   halevt_mount_check_dbus_error (&dbus_error);
   if (hal_device == NULL)
   {
-    fprintf (stderr, "Certainly out of memory, aborting\n");
+    fprintf (stderr, _("Certainly out of memory, aborting\n"));
     exit (1);
   }
   if (checked_udi->device == NULL)
   {
     if ((checked_udi->device = strdup (hal_device)) == NULL)
     {
-      fprintf (stderr, "Out of memory\n");
+      fprintf (stderr, _("Out of memory\n"));
       exit (1);
     }
   }
   else if (strcmp (hal_device, checked_udi->device))
   {
-    fprintf (stderr, "for udi %s, device in file %s isn't the device in hal: %s\n", checked_udi->udi, checked_udi->device, hal_device);
+    fprintf (stderr, _("for udi %s, device in file %s isn't the device in hal: %s\n"), checked_udi->udi, checked_udi->device, hal_device);
     if ((checked_udi->device = strdup (hal_device)) == NULL)
     {
       fprintf (stderr, "Out of memory\n");
@@ -234,7 +238,7 @@ int halevt_mount_check_udi(halevt_mount_udi *checked_udi, LibHalContext *hal_ctx
 
   if (! libhal_device_property_exists (hal_ctx, checked_udi->udi, "volume.fsusage", &dbus_error))
   {
-    fprintf (stderr, "udi %s don't seem to be a volume\n", checked_udi->udi);
+    fprintf (stderr, _("udi %s don't seem to be a volume\n"), checked_udi->udi);
     halevt_mount_check_dbus_error (&dbus_error);
     return 0;
   }
@@ -245,14 +249,14 @@ int halevt_mount_check_udi(halevt_mount_udi *checked_udi, LibHalContext *hal_ctx
   halevt_mount_check_dbus_error (&dbus_error);
   if (hal_fsusage == NULL)
   {
-    fprintf (stderr, "Certainly out of memory, aborting\n");
+    fprintf (stderr, _("Certainly out of memory, aborting\n"));
     exit (1);
   }
 
   if (strcmp (hal_fsusage, "filesystem"))
   {
     if (warn)
-      fprintf (stderr, "udi %s don't seem to contain a filesystem\n", checked_udi->udi);
+      fprintf (stderr, _("udi %s does not seem to contain a filesystem\n"), checked_udi->udi);
     return 0;
   }
   
@@ -274,7 +278,7 @@ int halevt_mount_check_udi(halevt_mount_udi *checked_udi, LibHalContext *hal_ctx
   if (! libhal_device_property_exists (hal_ctx, checked_udi->udi, "volume.is_mounted", &dbus_error))
   {
     if (warn)
-      fprintf (stderr, "udi %s don't have information about volume mounting\n", checked_udi->udi);
+      fprintf (stderr, _("udi %s don't have information about volume mounting\n"), checked_udi->udi);
     halevt_mount_check_dbus_error (&dbus_error);
     return 0;
   }
@@ -288,7 +292,7 @@ int halevt_mount_check_udi(halevt_mount_udi *checked_udi, LibHalContext *hal_ctx
   
     if (! libhal_device_property_exists (hal_ctx, checked_udi->udi, "volume.mount_point", &dbus_error))
     {
-      fprintf (stderr, "udi %s don't have the mountpoint property defined\n", checked_udi->udi);
+      fprintf (stderr, _("udi %s don't have the mountpoint property defined\n"), checked_udi->udi);
       halevt_mount_check_dbus_error (&dbus_error);
       return 0;
     }
@@ -298,23 +302,23 @@ int halevt_mount_check_udi(halevt_mount_udi *checked_udi, LibHalContext *hal_ctx
     halevt_mount_check_dbus_error (&dbus_error);
     if (hal_mountpoint == NULL)
     {
-      fprintf (stderr, "Certainly out of memory, aborting\n");
+      fprintf (stderr, _("Certainly out of memory, aborting\n"));
       exit (1);
     }
     if (checked_udi->mountpoint == NULL)
     {
       if ((checked_udi->mountpoint = strdup (hal_mountpoint)) == NULL)
       {
-        fprintf (stderr, "Out of memory\n");
+        fprintf (stderr, _("Out of memory\n"));
         exit (1);
       }
     }
     else if (strcmp (hal_mountpoint, checked_udi->mountpoint))
     {
-      fprintf (stderr, "for udi %s, mountpoint in file %s isn't the mountpoint in hal: %s\n", checked_udi->udi, checked_udi->mountpoint, hal_mountpoint);
+      fprintf (stderr, _("for udi %s, mountpoint in file %s isn't the mountpoint in hal: %s\n"), checked_udi->udi, checked_udi->mountpoint, hal_mountpoint);
       if ((checked_udi->mountpoint = strdup (hal_mountpoint)) == NULL)
       {
-        fprintf (stderr, "Out of memory\n");
+        fprintf (stderr, _("Out of memory\n"));
         exit (1);
       }
     }
@@ -390,11 +394,11 @@ int halevt_mount_print_udis (FILE *file, int print_ignore)
     {
       if (current_udi->ignore == 1)
       {
-        ignore_string = " (ignore true)";
+        ignore_string = _(" (ignore true)");
       }
       else if (current_udi->ignore == 2)
       {
-        ignore_string = " (ignore false)";
+        ignore_string = _(" (ignore false)");
       }
     }
 
@@ -442,7 +446,7 @@ halevt_mount_udi **halevt_mount_find_udi (const char *udi, const char *device,
 
   if ((list = (halevt_mount_udi **) malloc (list_size * sizeof(halevt_mount_udi *))) == NULL)
   {
-    fprintf (stderr, "Out of memory\n");
+    fprintf (stderr, _("Out of memory\n"));
     exit (1);
   }
   list[0] = NULL;
@@ -459,11 +463,11 @@ halevt_mount_udi **halevt_mount_find_udi (const char *udi, const char *device,
     { 
       if ((device != NULL) && (current_udi->device != NULL) && (strcmp (current_udi->device, device)))
       {
-        fprintf (stderr, "device found %s and device specified %s don't match\n", current_udi->device, device);
+        fprintf (stderr, _("device found %s and device specified %s don't match\n"), current_udi->device, device);
       }
       if ((mountpoint != NULL) && (current_udi->mountpoint != NULL) && (strcmp (current_udi->mountpoint, mountpoint)))
       {
-        fprintf (stderr, "mountpoint found %s and mountpoint specified %s don't match\n", current_udi->mountpoint, mountpoint);
+        fprintf (stderr, _("mountpoint found %s and mountpoint specified %s don't match\n"), current_udi->mountpoint, mountpoint);
       }
       /* 1 for the new element, 1 for the NULL pointer at the end */
       if ((list_nr + 2) > list_size)
@@ -471,7 +475,7 @@ halevt_mount_udi **halevt_mount_find_udi (const char *udi, const char *device,
         list_size = 2*list_size;
         if ((list = (halevt_mount_udi **) realloc (list, list_size * sizeof(halevt_mount_udi *))) == NULL)
         {
-          fprintf (stderr, "Out of memory\n");
+          fprintf (stderr, _("Out of memory\n"));
           exit (1);
         }
       }
@@ -501,7 +505,7 @@ void halevt_mount_umount (DBusConnection *dbus_connection, halevt_mount_udi *udi
        DBUS_TYPE_ARRAY, DBUS_TYPE_STRING, &options_array, 0, 
        DBUS_TYPE_INVALID)))
   {
-    fprintf (stderr, "Out of memory\n");
+    fprintf (stderr, _("Out of memory\n"));
     return;
   }
     
@@ -509,7 +513,7 @@ void halevt_mount_umount (DBusConnection *dbus_connection, halevt_mount_udi *udi
   if (((dbus_reply = dbus_connection_send_with_reply_and_block 
       (dbus_connection, dbus_msg, -1, &dbus_error)) == NULL) || dbus_error_is_set (&dbus_error))
   {
-    fprintf (stderr, "Unmount error for %s:\n", udi->udi);
+    fprintf (stderr, _("Unmount error for %s:\n"), udi->udi);
   }
   halevt_mount_check_dbus_error (&dbus_error);
 }
@@ -520,7 +524,7 @@ halevt_mount_udi *halevt_mount_new_udi (char *udi)
 
   if (new_udi == NULL)
   {
-     fprintf (stderr, "Out of memory\n");
+     fprintf (stderr, _("Out of memory\n"));
      exit (1);
   }
   new_udi->udi = udi;
@@ -548,7 +552,7 @@ halevt_mount_udi *halevt_mount_add_udi (char *udi, char *device, LibHalContext *
     halevt_mount_check_dbus_error (&dbus_error);
     if (all_devices == NULL)
     {
-      fprintf (stderr, "HAL didn't return any device\n");
+      fprintf (stderr, _("HAL didn't return any device\n"));
       exit (1); 
     }
 
@@ -566,7 +570,7 @@ halevt_mount_udi *halevt_mount_add_udi (char *udi, char *device, LibHalContext *
         {
           if ((udi != NULL) && (strcmp (udi, new_udi->udi)))
           {
-            fprintf (stderr, "Device %s is associated with udi %s, but udi %s was specified\n", device, new_udi->udi, udi);
+            fprintf (stderr, _("Device %s is associated with udi %s, but udi %s was specified\n"), device, new_udi->udi, udi);
           }
           new_udi->next = udi_device_mountpoint_root;
           udi_device_mountpoint_root = new_udi;
@@ -579,14 +583,14 @@ halevt_mount_udi *halevt_mount_add_udi (char *udi, char *device, LibHalContext *
 
   if (udi == NULL)
   {
-    fprintf (stderr, "The specified device %s wasn't found\n", device);
+    fprintf (stderr, _("The specified device %s wasn't found\n"), device);
     exit (1);
   }
 
   new_udi = halevt_mount_new_udi (udi);
   if (! halevt_mount_check_udi (new_udi, hal_ctx, 1))
   {
-    fprintf (stderr, "The specified udi %s doesn't seem to exist\n", udi);
+    fprintf (stderr, _("The specified udi %s doesn't seem to exist\n"), udi);
     exit (1);
   }
   new_udi->next = udi_device_mountpoint_root;
@@ -605,7 +609,7 @@ void halevt_mount_rewrite_device_file (const char *tmp_device_file, const char *
     {
       if (unlink (device_file) < 0)
       {
-        fprintf (stderr, "Cannot unlink %s: %s\n", device_file, strerror(errno));      
+        fprintf (stderr, _("Cannot unlink %s: %s\n"), device_file, strerror(errno));      
       }
     }
   }
@@ -613,20 +617,20 @@ void halevt_mount_rewrite_device_file (const char *tmp_device_file, const char *
   {
     if ((out_fd = fopen (tmp_device_file, "w")) == NULL)
     {
-      fprintf (stderr, "Error opening %s: %s\n", tmp_device_file, strerror (errno));
+      fprintf (stderr, _("Error opening %s: %s\n"), tmp_device_file, strerror (errno));
       exit (1);
     }
     if (! halevt_mount_print_udis (out_fd, 0)) { exit (1); }
     if (rename (tmp_device_file, device_file) <0)
     {
-      fprintf (stderr, "Renaming %s to %s failed: %s\n", tmp_device_file, device_file, strerror (errno));
+      fprintf (stderr, _("Renaming %s to %s failed: %s\n"), tmp_device_file, device_file, strerror (errno));
     }
   }
 }
 
 void usage()
 {
-  printf (
+  printf (_(
 " Usage: halevt-mount [option]\n\
         halevt-umount [option]\n\
  Mount or umount device through hal and keep a track of devices handled.\n\
@@ -660,6 +664,7 @@ void usage()
  available for halevt-mount and halevt-umount may become out of sync with\n\
  the state of the system. \n\
  "
+)
 ); 
 }
 
@@ -701,15 +706,19 @@ int main (int argc, char **argv)
   int system_user = 0;
   char *mask_string;
 
+  setlocale (LC_ALL, "");
+  bindtextdomain (PACKAGE, DATADIR "/locale/");
+  textdomain (PACKAGE);
+
   if ((options_array = (char **) malloc (sizeof(char *))) == NULL)
   {
-    fprintf (stderr, "Out of memory\n");
+    fprintf (stderr, _("Out of memory\n"));
     exit (1);
   }
 
   if ((passwd_struct = getpwuid(getuid())) == NULL)
   {
-    fprintf (stderr, "Error for getpwuid: %s\n", strerror (errno));
+    fprintf (stderr, _("Error for getpwuid: %s\n"), strerror (errno));
   }
   if ((! strcmp(passwd_struct->pw_name, HALEVT_USER_NAME)) || (getuid() == 0))
   {
@@ -725,54 +734,54 @@ int main (int argc, char **argv)
        case 'i':
          if ((directory = strdup(optarg)) == NULL)
          {
-           fprintf (stderr, "Out of memory\n");
+           fprintf (stderr, _("Out of memory\n"));
            exit (1);
          }
          break;
        case 'f':
          if ((device_file = strdup(optarg)) == NULL)
          {
-           fprintf (stderr, "Out of memory\n");
+           fprintf (stderr, _("Out of memory\n"));
            exit (1);
          }
          break;
        case 'u':
          if ((udi = strdup(optarg)) == NULL)
          {
-           fprintf (stderr, "Out of memory\n");
+           fprintf (stderr, _("Out of memory\n"));
            exit (1);
          }
          break;
        case 'n':
          if ((lockfile = strdup(optarg)) == NULL)
          {
-           fprintf (stderr, "Out of memory\n");
+           fprintf (stderr, _("Out of memory\n"));
            exit (1);
          }
          break;
        case 'd':
          if ((device = strdup(optarg)) == NULL)
          {
-           fprintf (stderr, "Out of memory\n");
+           fprintf (stderr, _("Out of memory\n"));
            exit (1);
          }
          break;
        case 'p':
          if ((mountpoint = strdup(optarg)) == NULL)
          {
-           fprintf (stderr, "Out of memory\n");
+           fprintf (stderr, _("Out of memory\n"));
            exit (1);
          }
        case 'o':
          option_nr++;
          if ((realloc (options_array, option_nr * sizeof(char *))) == NULL)
          {
-           fprintf (stderr, "Out of memory\n");
+           fprintf (stderr, _("Out of memory\n"));
            exit (1);
          }
          if ((options_array[option_nr - 1] = strdup(optarg)) == NULL)
          {
-           fprintf (stderr, "Out of memory\n");
+           fprintf (stderr, _("Out of memory\n"));
            exit (1);
          }
          break;
@@ -782,12 +791,12 @@ int main (int argc, char **argv)
            option_nr++;
            if ((realloc (options_array, option_nr * sizeof(char *))) == NULL)
            {
-             fprintf (stderr, "Out of memory\n");
+             fprintf (stderr, _("Out of memory\n"));
              exit (1);
            }
            if ((mask_string = (char *) malloc ((1 + strlen (optarg) + strlen (MASKOPTSTR)) * sizeof(char))) == NULL)
            {
-             fprintf (stderr, "Out of memory\n");
+             fprintf (stderr, _("Out of memory\n"));
              exit (1);
            }
            strcpy (mask_string, MASKOPTSTR);
@@ -795,7 +804,7 @@ int main (int argc, char **argv)
            options_array[option_nr - 1] = mask_string;
            if ((options_array[option_nr - 1] = strdup(mask_string)) == NULL)
            {
-             fprintf (stderr, "Out of memory\n");
+             fprintf (stderr, _("Out of memory\n"));
              exit (1);
            }
            free (mask_string);
@@ -862,12 +871,12 @@ int main (int argc, char **argv)
     {
       if ((home = getenv("HOME")) == NULL)
       {
-        fprintf (stderr, "Cannot getenv HOME\n");
+        fprintf (stderr, _("Cannot getenv HOME\n"));
         exit (1);
       }
       if ((directory = malloc ((1 + strlen (home) + strlen (DIRHOME)) * sizeof(char))) == NULL)
       {
-        fprintf (stderr, "Out of memory\n"); 
+        fprintf (stderr, _("Out of memory\n")); 
         exit(1);
       }
       strcpy (directory, home);
@@ -879,7 +888,7 @@ int main (int argc, char **argv)
   {
     if ((lockfile = malloc ((1 + strlen (directory) + strlen (LOCKFILENAME)) * sizeof(char))) == NULL)
     {
-      fprintf (stderr, "Out of memory\n"); 
+      fprintf (stderr, _("Out of memory\n")); 
       exit(1);
     }
     strcpy (lockfile, directory);
@@ -890,7 +899,7 @@ int main (int argc, char **argv)
   {
     if ((device_file = malloc ((1 + strlen (directory) + strlen (DEVICEFILENAME)) * sizeof(char))) == NULL)
     {
-      fprintf (stderr, "Out of memory\n"); 
+      fprintf (stderr, _("Out of memory\n")); 
       exit(1);
     }
     strcpy (device_file, directory);
@@ -899,7 +908,7 @@ int main (int argc, char **argv)
 
   if ((tmp_device_file = malloc ((1 + strlen (device_file) + strlen(TMPPOSTFIX)) * sizeof(char))) == NULL)
   {
-    fprintf (stderr, "Out of memory\n"); 
+    fprintf (stderr, _("Out of memory\n"));
     exit(1);
   }
   strcpy (tmp_device_file, device_file);
@@ -909,24 +918,24 @@ int main (int argc, char **argv)
   {
     if (mkdir (directory, 0777) < 0)
     {
-      fprintf (stderr, "Cannot create directory %s: %s\n", directory, strerror (errno));
+      fprintf (stderr, _("Cannot create directory %s: %s\n"), directory, strerror (errno));
       exit (1);
     }
   }
   if ((fd_lock = open (lockfile, O_RDWR | O_CREAT, 0644)) < 0)
   {
-    fprintf (stderr, "Error opening lock file %s: %s\n", lockfile, strerror (errno));
+    fprintf (stderr, _("Error opening lock file %s: %s\n"), lockfile, strerror (errno));
   }
   if (lockf (fd_lock, F_LOCK, 0) < 0)
   {
-    fprintf (stderr, "Error locking lock file %s: %s\n", lockfile, strerror (errno));
+    fprintf (stderr, _("Error locking lock file %s: %s\n"), lockfile, strerror (errno));
   }
   
   if (stat (tmp_device_file,  &statbuf) == 0)
   {
     if (unlink (tmp_device_file) < 0)
     {
-      fprintf (stderr, "Cannot unlink %s: %s\n", tmp_device_file, strerror(errno));      
+      fprintf (stderr, _("Cannot unlink %s: %s\n"), tmp_device_file, strerror(errno));      
     }
   }
 
@@ -936,7 +945,7 @@ int main (int argc, char **argv)
     {
       if (unlink (device_file) < 0)
       {
-        fprintf (stderr, "Cannot unlink %s: %s\n", device_file, strerror(errno));
+        fprintf (stderr, _("Cannot unlink %s: %s\n"), device_file, strerror(errno));
       }
     }
     goto end;
@@ -946,7 +955,7 @@ int main (int argc, char **argv)
   {
     if (stat (device_file,  &statbuf) == 0)
     {
-      if (! halevt_mount_parse_file (device_file)) { fprintf (stderr, "Error parsing %s\n", device_file); }
+      if (! halevt_mount_parse_file (device_file)) { fprintf (stderr, _("Error parsing %s\n"), device_file); }
       else { halevt_mount_print_udis (stdout, 0); }
     }
     goto end;
@@ -955,14 +964,14 @@ int main (int argc, char **argv)
    hal informations */
   if ((hal_ctx = libhal_ctx_new()) == NULL)
   {
-    fprintf (stderr, "Failed to create HAL context\n");
+    fprintf (stderr, _("Failed to create HAL context\n"));
     exit(1);
   }
   dbus_error_init (&dbus_error);
   dbus_connection = dbus_bus_get (DBUS_BUS_SYSTEM, &dbus_error);
   if (dbus_error_is_set (&dbus_error))
   {
-    fprintf (stderr, "Error connecting to D-BUS system bus: %s", dbus_error.message);
+    fprintf (stderr, _("Error connecting to D-BUS system bus: %s"), dbus_error.message);
     dbus_error_free (&dbus_error);
     exit(1);
   }
@@ -970,7 +979,7 @@ int main (int argc, char **argv)
 
   if (!libhal_ctx_init (hal_ctx, &dbus_error))
   {
-    fprintf (stderr, "Error initializing HAL");
+    fprintf (stderr, _("Error initializing HAL"));
     exit(1);
   }
   halevt_mount_sync_udi (device_file, hal_ctx);
@@ -982,7 +991,7 @@ int main (int argc, char **argv)
   }
   else if (! strcmp (cmd, "list"))
   { /* do_all is true. We show all the devices, including those not handled */
-    fprintf (stdout, "Devices handled:\n");
+    fprintf (stdout, _("Devices handled:\n"));
     halevt_mount_print_udis (stdout, 0);
 
     /* get and add all the devices */
@@ -990,7 +999,7 @@ int main (int argc, char **argv)
     halevt_mount_check_dbus_error (&dbus_error);
     if (all_devices == NULL)
     {
-      fprintf (stderr, "HAL didn't return any device\n");
+      fprintf (stderr, _("HAL didn't return any device\n"));
       exit (1); 
     }
     /* reuse the same udi root list */
@@ -1006,22 +1015,26 @@ int main (int argc, char **argv)
       }
       current_device++;
     }
-    fprintf (stdout, "\nAll devices:\n");
+    fprintf (stdout, _("\nAll devices:\n"));
     halevt_mount_print_udis (stdout, 1);
   }
   else if ((! strcmp (cmd, "mount")) || (! strcmp (cmd, "add")))
   {
     if ((udi == NULL) && (device == NULL))
     {
-      fprintf (stderr, "An udi or a device is needed\n");
+      fprintf (stderr, _("An udi or a device is needed\n"));
       exit (1);
     }
     udi_found = halevt_mount_find_udi (udi, device, NULL, NULL);
-    if (udi_found[0] == NULL) { halevt_mount_add_udi (udi, device, hal_ctx); }
+    if (udi_found[0] == NULL) 
+    { 
+       new_device_udi = halevt_mount_add_udi (udi, device, hal_ctx); 
+    }
+    else { new_device_udi = udi_found[0]; }
     /* write the new udi structure to the temporary file */
     if ((out_fd = fopen (tmp_device_file, "w")) == NULL)
     {
-      fprintf (stderr, "Error opening %s: %s\n", tmp_device_file, strerror (errno));
+      fprintf (stderr, _("Error opening %s: %s\n"), tmp_device_file, strerror (errno));
       exit (1);
     }
     if (! halevt_mount_print_udis (out_fd, 0)) { exit (1); }
@@ -1031,16 +1044,16 @@ int main (int argc, char **argv)
     /* if we were just adding a new device we are done now */
       if (rename (tmp_device_file, device_file) < 0)
       {
-        fprintf (stderr, "Renaming %s to %s after add failed: %s\n", tmp_device_file, device_file, strerror (errno));
+        fprintf (stderr, _("Renaming %s to %s after add failed: %s\n"), tmp_device_file, device_file, strerror (errno));
         exit (1); 
       }
       goto end; 
     }
     /* now perform the mount */
-    if ((dbus_msg = dbus_message_new_method_call ("org.freedesktop.Hal", udi,
-       "org.freedesktop.Hal.Device.Volume", "Mount")) == NULL)
+    if ((dbus_msg = dbus_message_new_method_call ("org.freedesktop.Hal", 
+       new_device_udi->udi, "org.freedesktop.Hal.Device.Volume", "Mount")) == NULL)
     {
-      fprintf (stderr, "Out of memory\n");
+      fprintf (stderr, _("Out of memory\n"));
       exit (1);
     }
 
@@ -1059,14 +1072,14 @@ int main (int argc, char **argv)
         (dbus_connection, dbus_msg, -1, &dbus_error)) == NULL)
           || dbus_error_is_set (&dbus_error))
     {
-      fprintf (stderr, "Mount error for %s:\n", udi);
+      fprintf (stderr, _("Mount error for %s:\n"), udi);
       halevt_mount_check_dbus_error (&dbus_error);
       exit (1);
     }
     halevt_mount_check_dbus_error (&dbus_error);
     if (rename (tmp_device_file, device_file) <0)
     {
-      fprintf (stderr, "Renaming %s to %s after a mount failed: %s\n", tmp_device_file, device_file, strerror (errno));
+      fprintf (stderr, _("Renaming %s to %s after a mount failed: %s\n"), tmp_device_file, device_file, strerror (errno));
     }
   }
   else if ((! strcmp (cmd, "umount")) || (! strcmp (cmd, "clean")))
@@ -1074,7 +1087,7 @@ int main (int argc, char **argv)
     char *searched_device_mountpoint = NULL;
     if (udi == NULL && device == NULL && mountpoint == NULL && (!arg_index) && (!do_all))
     {
-      fprintf (stderr, "An argument or -a is needed\n");
+      fprintf (stderr, _("An argument or -a is needed\n"));
       exit (1);
     }
 
@@ -1151,7 +1164,7 @@ end:
   
   if (close (fd_lock) <0)
   {
-    fprintf (stderr, "Error on close %s: %s\n", lockfile, strerror(errno));
+    fprintf (stderr, _("Error on close %s: %s\n"), lockfile, strerror(errno));
   }
 
   return 0;
